@@ -2,6 +2,7 @@ import os
 import re
 import sys
 import random
+import subprocess
 
 
 readme = """
@@ -30,7 +31,7 @@ def readCustomYML(text):
     dic = {}
 
     for t in text:
-        t = t.split(":")
+        t = t.split(":", maxsplit=1)
         key = t[0]
         val = re.sub("#.*$", "", t[1]).strip()
 
@@ -118,10 +119,12 @@ def main():
     counter = filesToOpen
 
     for f in finalSample:
-        with open(dictionary[f], "r", encoding="utf8") as ftIn:
+        open_yes = False
+        with open(dictionary[f], "r+", encoding="utf8") as ftIn:
             MIUcontent = ftIn.read()
 
             if re.search(r"reviewed\s+:\s+(False|NOT REVIEWED)", MIUcontent):
+                open_yes = True
                 # insert the name of the reviewer
                 if re.search(r"reviewer\s+:", MIUcontent):
                     MIUcontent = re.sub(r"(reviewed\s+:)[^\n]+\n", r"\1 NOT REVIEWED\n", MIUcontent)
@@ -133,30 +136,31 @@ def main():
 
                 # inserting the name of the reviewer; the reviewer will have to only change the status tag
                 # upon saving and closing
-                with open(dictionary[f], "w", encoding="utf8") as ftOut:
-                    ftOut.write(MIUcontent)
+                ftIn.seek(0)
+                ftIn.write(MIUcontent)
+                ftIn.truncate()
 
-                # NOW OPENING IN KATE FOR REVIEW
-                if osVar == "mac":
-                    # open on mac
-                    lineToRun = "open -a %s %s" % (pathToKate, dictionary[f])
-                    os.system(lineToRun)
+        if open_yes:
+            # NOW OPENING IN KATE FOR REVIEW
+            if osVar == "mac":
+                # open on mac
+                # lineToRun = "open -a %s %s" % (pathToKate, dictionary[f])
+                # os.system(lineToRun)
+                subprocess.run(['open', '-a', pathToKate, dictionary[f]])
 
-                elif osVar == "lin":
-                    lineToRun = f"{pathToKate} {dictionary[f]}"
-                    os.system(lineToRun)
-                elif osVar == "win":
-                    lineToRun = f"Start-Process -FilePath \"{pathToKate}\" {dictionary[f]}"
-                    os.system(lineToRun)
-                else:
-                    print("Operating system is incorrect. Use: mac, lin, or win")
-                    sys.exit()
+            elif osVar == "lin":
+                subprocess.run([pathToKate, dictionary[f]])
+            elif osVar == "win":
+                subprocess.run([path, dictionary[f]])
+            else:
+                print("Operating system is incorrect. Use: mac, lin, or win")
+                sys.exit()
 
-                print("\t- ", f)
+            print("\t- ", f)
 
-                counter -= 1
-                if counter == 0:
-                    break
+            counter -= 1
+            if counter == 0:
+                break
 
     print("======================================================================================")
     print("REVIEW MIU FILES IN KATE; WHEN DONE, CHANGE STATUS TO `REVIEWED`, SAVE, AND CLOSE ====")
