@@ -13,7 +13,7 @@ Functions:
 
 from glob import glob
 from os.path import split, splitext
-from typing import List, Optional
+from typing import List, Literal, Optional
 
 from eis1600.markdown.re_patterns import FIXED_POETRY_OLD_PATH_PATTERN
 
@@ -31,10 +31,7 @@ def get_entry(file_name: str, checked_entry: bool) -> str:
     return '- [' + x + '] ' + file_name
 
 
-def write_to_readme(
-        path: str, files: List[str], which: str, ext: Optional[str] = None, checked: bool = False, remove_duplicates:
-        bool = False
-) -> None:
+def write_to_readme(path: str, files: List[str], which: str, ext: Optional[str] = None, checked: bool = False) -> None:
     """Write list of successfully processed files to the README.
 
     Write processed files to the respective section in the README, sorted into existing lists.
@@ -44,8 +41,6 @@ def write_to_readme(
     :param str which: The section heading from the README indicating the section to write the list of files to.
     :param str or None ext: File extension of the files at the end of the process, optional.
     :param bool checked: Indicator if the checkboxes of the files are ticked, defaults to False.
-    :param bool remove_duplicates: If True duplicate entries will be removed (needed for the list of fixed poetry),
-    defaults to False.
     """
 
     file_list = []
@@ -88,9 +83,8 @@ def write_to_readme(
             else:
                 file_list.append(uri + ext + '\n')
 
-        # Duplicates only occur in the Fixed poetry section
-        if remove_duplicates:
-            file_list = list(set(file_list))
+        # Remove duplicates
+        file_list = list(set(file_list))
         # Sort list of all entries (old and new)
         file_list.sort()
 
@@ -172,7 +166,7 @@ def update_texts_fixed_poetry_readme(path: str, which: str) -> None:
         files_text = readme_h.read()
     files_text = FIXED_POETRY_OLD_PATH_PATTERN.sub('', files_text)
     file_list = files_text.split('\n')
-    write_to_readme(path, file_list, which, None, False, True)
+    write_to_readme(path, file_list, which)
 
 
 def get_files_from_eis1600_dir(
@@ -197,6 +191,7 @@ def get_files_from_eis1600_dir(
         author, work, text = file.split('.')[:3]
         file_path = path + '/'.join([author, '.'.join([author, work]), '.'.join([author, work, text])]) + '.'
         if file_ext_to and not glob(file_path + file_ext_to):
+            # Only do if the target file does not exist
             if type(file_ext_from) == list:
                 for ext in file_ext_from:
                     tmp = glob(file_path + ext)
@@ -205,31 +200,39 @@ def get_files_from_eis1600_dir(
             else:
                 files.extend(glob(file_path + file_ext_from))
         elif not file_ext_to:
+            # Do if file ending stays the same
             files.extend(glob(file_path + file_ext_from))
     return files
 
 
-def travers_eis1600_dir(path, file_ext_from, file_ext_to):
+def get_path_to_other_repo(infile: str, which: Literal['MIU', 'TEXT']) -> str:
     """
 
-    TODO is this still needed?
-
-    :param path:
-    :param file_ext_from:
-    :param file_ext_to:
-    :return:
+    :param str infile: file which gives URI of the text.
+    :param Literal which: Indicating which repo you want to get the path to, accepts 'MIU' or 'TEXT'.
+    :return str: path to the same URI in the requested repo
     """
-    path += 'data/*/*/'
-    in_files = glob(path + file_ext_from)
-    if not file_ext_to:
-        return in_files
+    out_path = '../'
+
+    if 'data' in infile:
+        out_path += infile.split('data')[0][2:]
+    elif infile == './':
+        pass
     else:
-        exclude_files = glob(path + file_ext_to)
-        files = []
+        depth = len(infile.split('/'))
+        print(depth)
+        if depth == 1:
+            out_path += '../../../'
+        elif depth == 2:
+            out_path += '../../'
+        elif depth == 3:
+            out_path += '../'
+        else:
+            out_path += '../'
 
-        for file in in_files:
-            path, ext = splitext(file)
-            if not path + '.' + file_ext_to in exclude_files:
-                files.append(file)
+    if which == 'MIU':
+        out_path += 'OpenITI_EIS1600_MIUs/data/'
+    else:
+        out_path += 'OpenITI_EIS1600_Texts/data/'
 
-        return files
+    return out_path
